@@ -1,11 +1,11 @@
-package HTTP::Daemon; # git description: v6.08-2-g8ff349c
+package HTTP::Daemon; # git description: v6.10-3-gb2031d1
 
 # ABSTRACT: A simple http server class
 
 use strict;
 use warnings;
 
-our $VERSION = '6.09'; # TRIAL
+our $VERSION = '6.11'; # TRIAL
 
 use Socket ();
 use IO::Socket::IP;
@@ -47,6 +47,7 @@ sub url {
     my $self = shift;
 
     my $host = $self->sockhost;
+    $host =~ s/%/%25/g;
     $host = "127.0.0.1" if $host eq "0.0.0.0";
     $host = "::1"       if $host eq "::";
     $host = "[$host]"   if $self->sockdomain == Socket::AF_INET6;
@@ -602,7 +603,7 @@ HTTP::Daemon - A simple http server class
 
 =head1 VERSION
 
-version 6.09
+version 6.11
 
 =head1 SYNOPSIS
 
@@ -914,17 +915,17 @@ Gisle Aas <gisle@activestate.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Ville Skyttä Olaf Alders Mark Stosberg Karen Etheridge Shoichi Kaji Chase Whitener Slaven Rezic Zefram Bron Gondwana Petr Písař Tom Hukins Mike Schilli Alexey Tourbin Ian Kilgore Jacob J Ondrej Hanak Perlover Peter Rabbitson Robert Stone Rolf Grossmann Sean M. Burke Spiros Denaxas Steve Hay Todd Lipcon Tony Finch Toru Yamaguchi Yuri Karaban amire80 jefflee john9art murphy phrstbrn ruff Adam Kennedy sasao Sjogren Alex Kapranoff Andreas J. Koenig Bill Mann DAVIDRW Daniel Hedlund David E. Wheeler FWILES Father Chrysostomos Ferenc Erki Gavin Peters Graeme Thompson Hans-H. Froehlich
+=for stopwords Olaf Alders Ville Skyttä Mark Stosberg Karen Etheridge Shoichi Kaji Chase Whitener Slaven Rezic Zefram Petr Písař Tom Hukins Alexey Tourbin Mike Schilli Bron Gondwana Ian Kilgore Jacob J Ondrej Hanak Perlover Peter Rabbitson Robert Stone Rolf Grossmann Sean M. Burke Spiros Denaxas Steve Hay Todd Lipcon Tony Finch Toru Yamaguchi Yuri Karaban amire80 jefflee john9art murphy phrstbrn ruff Adam Kennedy sasao Sjogren Alex Kapranoff Andreas J. Koenig Bill Mann DAVIDRW Daniel Hedlund David E. Wheeler FWILES Father Chrysostomos Ferenc Erki Gavin Peters Graeme Thompson Hans-H. Froehlich
 
 =over 4
 
 =item *
 
-Ville Skyttä <ville.skytta@iki.fi>
+Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
-Olaf Alders <olaf@wundersolutions.com>
+Ville Skyttä <ville.skytta@iki.fi>
 
 =item *
 
@@ -952,10 +953,6 @@ Zefram <zefram@fysh.org>
 
 =item *
 
-Bron Gondwana <brong@fastmail.fm>
-
-=item *
-
 Petr Písař <ppisar@redhat.com>
 
 =item *
@@ -964,11 +961,15 @@ Tom Hukins <tom@eborcom.com>
 
 =item *
 
+Alexey Tourbin <at@altlinux.ru>
+
+=item *
+
 Mike Schilli <mschilli@yahoo-inc.com>
 
 =item *
 
-Alexey Tourbin <at@altlinux.ru>
+Bron Gondwana <brong@fastmail.fm>
 
 =item *
 
